pub enum ZabbixError {
Network(Error),
Json(Error),
VersionParse(Error),
ApiError {
message: String,
data: String,
},
Other(String),
}Expand description
Error type for Zabbix interactions.
Errors
This method will return a ZabbixError if:
- The provided URL is invalid or unreachable (
ZabbixError::Network). - The server responds with invalid JSON (
ZabbixError::Json). - The server returns a version string that cannot be parsed by semantic versioning rules (
ZabbixError::VersionParse). - The server returns an API error (
ZabbixError::ApiError). If future Zabbix versions return a different error format, this enum variant may need to be updated.
Variants